@@ -25,8 +25,8 @@ from pycti.entities.opencti_stix_domain_object import StixDomainObject
 from pycti.entities.opencti_stix_cyber_observable import StixCyberObservable
 from pycti.entities.opencti_stix_core_relationship import StixCoreRelationship
 from pycti.entities.opencti_stix_sighting_relationship import StixSightingRelationship
-from pycti.entities.opencti_stix_cyber_observable_relation import (
-    StixCyberObservableRelation,
+from pycti.entities.opencti_stix_cyber_observable_relationship import (
+    StixCyberObservableRelationship,
 )
 from pycti.entities.opencti_identity import Identity
 from pycti.entities.opencti_location import Location
@@ -101,6 +101,7 @@ class OpenCTIApiClient:
         self.api_token = token
         self.api_url = url + "/graphql"
         self.request_headers = {"Authorization": "Bearer " + token}
+        self.session = requests.session()
 
         # Define the dependencies
         self.work = OpenCTIApiWork(self)
@@ -119,7 +120,7 @@ class OpenCTIApiClient:
         self.stix_cyber_observable = StixCyberObservable(self, File)
         self.stix_core_relationship = StixCoreRelationship(self)
         self.stix_sighting_relationship = StixSightingRelationship(self)
-        self.stix_observable_relation = StixCyberObservableRelation(self)
+        self.stix_cyber_observable_relationship = StixCyberObservableRelationship(self)
         self.identity = Identity(self)
         self.location = Location(self)
         self.threat_actor = ThreatActor(self)
@@ -241,7 +242,7 @@ class OpenCTIApiClient:
                     multipart_files.append(file_multi)
                     file_index += 1
             # Send the multipart request
-            r = requests.post(
+            r = self.session.post(
                 self.api_url,
                 data=multipart_data,
                 files=multipart_files,
@@ -251,7 +252,7 @@ class OpenCTIApiClient:
             )
         # If no
         else:
-            r = requests.post(
+            r = self.session.post(
                 self.api_url,
                 json={"query": query, "variables": variables},
                 headers=self.request_headers,
@@ -263,7 +264,11 @@ class OpenCTIApiClient:
             result = r.json()
             if "errors" in result:
                 main_error = result["errors"][0]
-                error_name = main_error["name"]
+                error_name = (
+                    main_error["name"]
+                    if "name" in main_error
+                    else main_error["message"]
+                )
                 if "data" in main_error and "reason" in main_error["data"]:
                     logging.error(main_error["data"]["reason"])
                     raise ValueError(
@@ -291,7 +296,7 @@ class OpenCTIApiClient:
         :rtype: str or bytes
         """
 
-        r = requests.get(fetch_uri, headers=self.request_headers)
+        r = self.session.get(fetch_uri, headers=self.request_headers)
         if binary:
             return r.content
         return r.text
@@ -340,7 +345,12 @@ class OpenCTIApiClient:
             query LogsWorkerConfig {
                 logsWorkerConfig {
                     elasticsearch_url
+                    elasticsearch_proxy
                     elasticsearch_index
+                    elasticsearch_username
+                    elasticsearch_password
+                    elasticsearch_api_key
+                    elasticsearch_ssl_reject_unauthorized
                 }
             }
         """
