@@ -1,8 +1,6 @@
 # coding: utf-8
 
 import json
-from pycti.utils.constants import CustomProperties
-from pycti.utils.opencti_stix2 import SPEC_VERSION
 
 
 class Malware:
@@ -10,92 +8,75 @@ class Malware:
         self.opencti = opencti
         self.properties = """
             id
-            stix_id_key
-            stix_label
+            standard_id
             entity_type
             parent_types
-            name
-            alias
-            description
-            is_family
-            graph_data
-            created
-            modified            
+            spec_version
             created_at
             updated_at
-            killChainPhases {
-                edges {
-                    node {
-                        id
-                        entity_type
-                        stix_id_key
-                        kill_chain_name
-                        phase_name
-                        phase_order
-                        created
-                        modified
-                    }
-                    relation {
-                        id
-                    }
-                }
-            }
-            createdByRef {
-                node {
+            createdBy {
+                ... on Identity {
                     id
+                    standard_id
                     entity_type
-                    stix_id_key
-                    stix_label
+                    parent_types
+                    spec_version
                     name
-                    alias
                     description
+                    roles
+                    contact_information
+                    x_opencti_aliases
                     created
                     modified
-                    ... on Organization {
-                        organization_class
-                    }
+                    objectLabel {
+                        edges {
+                            node {
+                                id
+                                value
+                                color
+                            }
+                        }
+                    }                    
                 }
-                relation {
-                    id
+                ... on Organization {
+                    x_opencti_organization_type
+                    x_opencti_reliability
                 }
-            }            
-            markingDefinitions {
+                ... on Individual {
+                    x_opencti_firstname
+                    x_opencti_lastname
+                }
+            }
+            objectMarking {
                 edges {
                     node {
                         id
+                        standard_id
                         entity_type
-                        stix_id_key
                         definition_type
                         definition
-                        level
-                        color
                         created
                         modified
-                    }
-                    relation {
-                        id
+                        x_opencti_order
+                        x_opencti_color
                     }
                 }
             }
-            tags {
+            objectLabel {
                 edges {
                     node {
                         id
-                        tag_type
                         value
                         color
                     }
-                    relation {
-                        id
-                    }
                 }
             }
             externalReferences {
                 edges {
                     node {
                         id
+                        standard_id
                         entity_type
-                        stix_id_key
                         source_name
                         description
                         url
@@ -104,11 +85,36 @@ class Malware:
                         created
                         modified
                     }
-                    relation {
+                }
+            }
+            revoked
+            confidence
+            created
+            modified
+            name
+            description
+            aliases
+            malware_types
+            is_family
+            first_seen
+            last_seen
+            architecture_execution_envs
+            implementation_languages
+            capabilities
+            killChainPhases {
+                edges {
+                    node {
                         id
+                        standard_id                            
+                        entity_type
+                        kill_chain_name
+                        phase_name
+                        x_opencti_order
+                        created
+                        modified
                     }
                 }
-            }         
+            }
         """
 
     """
@@ -224,18 +230,29 @@ class Malware:
         :return Malware object
     """
 
-    def create_raw(self, **kwargs):
-        name = kwargs.get("name", None)
-        description = kwargs.get("description", None)
-        is_family = kwargs.get("is_family", False)
-        alias = kwargs.get("alias", None)
-        id = kwargs.get("id", None)
-        stix_id_key = kwargs.get("stix_id_key", None)
+    def create(self, **kwargs):
+        stix_id = kwargs.get("stix_id", None)
+        created_by = kwargs.get("createdBy", None)
+        object_marking = kwargs.get("objectMarking", None)
+        object_label = kwargs.get("objectLabel", None)
+        external_references = kwargs.get("externalReferences", None)
+        revoked = kwargs.get("revoked", None)
+        confidence = kwargs.get("confidence", None)
+        lang = kwargs.get("lang", None)
         created = kwargs.get("created", None)
         modified = kwargs.get("modified", None)
-        created_by_ref = kwargs.get("createdByRef", None)
-        marking_definitions = kwargs.get("markingDefinitions", None)
-        tags = kwargs.get("tags", None)
+        name = kwargs.get("name", None)
+        description = kwargs.get("description", "")
+        aliases = kwargs.get("aliases", None)
+        malware_types = kwargs.get("malware_types", None)
+        is_family = kwargs.get("is_family", None)
+        first_seen = kwargs.get("first_seen", None)
+        last_seen = kwargs.get("last_seen", None)
+        architecture_execution_envs = kwargs.get("architecture_execution_envs", None)
+        implementation_languages = kwargs.get("implementation_languages", None)
+        capabilities = kwargs.get("capabilities", None)
+        kill_chain_phases = kwargs.get("killChainPhases", None)
+        update = kwargs.get("update", False)
 
         if name is not None and description is not None:
             self.opencti.log("info", "Creating Malware {" + name + "}.")
@@ -243,7 +260,7 @@ class Malware:
                 mutation MalwareAdd($input: MalwareAddInput) {
                     malwareAdd(input: $input) {
                         id
-                        stix_id_key
+                        standard_id
                         entity_type
                         parent_types
                     }
@@ -253,17 +270,28 @@ class Malware:
                 query,
                 {
                     "input": {
-                        "name": name,
-                        "description": description,
-                        "is_family": is_family,
-                        "alias": alias,
-                        "internal_id_key": id,
-                        "stix_id_key": stix_id_key,
+                        "stix_id": stix_id,
+                        "createdBy": created_by,
+                        "objectMarking": object_marking,
+                        "objectLabel": object_label,
+                        "externalReferences": external_references,
+                        "revoked": revoked,
+                        "confidence": confidence,
+                        "lang": lang,
                         "created": created,
                         "modified": modified,
-                        "createdByRef": created_by_ref,
-                        "markingDefinitions": marking_definitions,
-                        "tags": tags,
+                        "name": name,
+                        "description": description,
+                        "aliases": aliases,
+                        "malware_types": malware_types,
+                        "is_family": is_family,
+                        "first_seen": first_seen,
+                        "last_seen": last_seen,
+                        "architecture_execution_envs": architecture_execution_envs,
+                        "implementation_languages": implementation_languages,
+                        "capabilities": capabilities,
+                        "killChainPhases": kill_chain_phases,
+                        "update": update,
                     }
                 },
             )
@@ -274,141 +302,72 @@ class Malware:
             )
 
     """
-        Create a Malware object only if it not exists, update it on request
+        Import an Malware object from a STIX2 object
 
-        :param name: the name of the Malware
+        :param stixObject: the Stix-Object Malware
         :return Malware object
     """
 
-    def create(self, **kwargs):
-        name = kwargs.get("name", None)
-        description = kwargs.get("description", None)
-        is_family = kwargs.get("is_family", False)
-        alias = kwargs.get("alias", None)
-        id = kwargs.get("id", None)
-        stix_id_key = kwargs.get("stix_id_key", None)
-        created = kwargs.get("created", None)
-        modified = kwargs.get("modified", None)
-        created_by_ref = kwargs.get("createdByRef", None)
-        marking_definitions = kwargs.get("markingDefinitions", None)
-        tags = kwargs.get("tags", None)
+    def import_from_stix2(self, **kwargs):
+        stix_object = kwargs.get("stixObject", None)
+        extras = kwargs.get("extras", {})
         update = kwargs.get("update", False)
-        custom_attributes = """
-            id
-            entity_type
-            name
-            description
-            alias
-            ... on Malware {
-                is_family
-            } 
-            createdByRef {
-                node {
-                    id
-                }
-            }
-        """
-        object_result = self.opencti.stix_domain_entity.get_by_stix_id_or_name(
-            types=["Malware"],
-            stix_id_key=stix_id_key,
-            name=name,
-            customAttributes=custom_attributes,
-        )
-        if object_result is not None:
-            if update or object_result["createdByRefId"] == created_by_ref:
-                # name
-                if object_result["name"] != name:
-                    self.opencti.stix_domain_entity.update_field(
-                        id=object_result["id"], key="name", value=name
-                    )
-                    object_result["name"] = name
-                # description
-                if (
-                    self.opencti.not_empty(description)
-                    and object_result["description"] != description
-                ):
-                    self.opencti.stix_domain_entity.update_field(
-                        id=object_result["id"], key="description", value=description
-                    )
-                    object_result["description"] = description
-                # is_family
-                if (
-                    self.opencti.not_empty(is_family)
-                    and object_result["is_family"] != is_family
-                ):
-                    self.opencti.stix_domain_entity.update_field(
-                        id=object_result["id"],
-                        key="is_family",
-                        value=str(is_family).lower(),
-                    )
-                    object_result["is_family"] = is_family
-                # alias
-                if self.opencti.not_empty(alias) and object_result["alias"] != alias:
-                    if "alias" in object_result:
-                        new_aliases = object_result["alias"] + list(
-                            set(alias) - set(object_result["alias"])
-                        )
-                    else:
-                        new_aliases = alias
-                    self.opencti.stix_domain_entity.update_field(
-                        id=object_result["id"], key="alias", value=new_aliases
-                    )
-                    object_result["alias"] = new_aliases
-            return object_result
-        else:
-            return self.create_raw(
-                name=name,
-                description=description,
-                is_family=is_family,
-                alias=alias,
-                id=id,
-                stix_id_key=stix_id_key,
-                created=created,
-                modified=modified,
-                createdByRef=created_by_ref,
-                markingDefinitions=marking_definitions,
-                tags=tags,
-            )
-
-    """
-        Export an Malware object in STIX2
-    
-        :param id: the id of the Malware
-        :return Malware object
-    """
-
-    def to_stix2(self, **kwargs):
-        id = kwargs.get("id", None)
-        mode = kwargs.get("mode", "simple")
-        max_marking_definition_entity = kwargs.get(
-            "max_marking_definition_entity", None
-        )
-        entity = kwargs.get("entity", None)
-        if id is not None and entity is None:
-            entity = self.read(id=id)
-        if entity is not None:
-            malware = dict()
-            malware["id"] = entity["stix_id_key"]
-            malware["type"] = "malware"
-            malware["spec_version"] = SPEC_VERSION
-            malware["name"] = entity["name"]
-            if self.opencti.not_empty(entity["stix_label"]):
-                malware["labels"] = entity["stix_label"]
-            else:
-                malware["labels"] = ["malware"]
-            if self.opencti.not_empty(entity["description"]):
-                malware["description"] = entity["description"]
-            if self.opencti.not_empty(entity["is_family"]):
-                malware["is_family"] = entity["is_family"]
-            else:
-                malware["is_family"] = False
-            malware["created"] = self.opencti.stix2.format_date(entity["created"])
-            malware["modified"] = self.opencti.stix2.format_date(entity["modified"])
-            if self.opencti.not_empty(entity["alias"]):
-                malware[CustomProperties.ALIASES] = entity["alias"]
-            malware[CustomProperties.ID] = entity["id"]
-            return self.opencti.stix2.prepare_export(
-                entity, malware, mode, max_marking_definition_entity
+        if stix_object is not None:
+            return self.create(
+                stix_id=stix_object["id"],
+                createdBy=extras["created_by_id"]
+                if "created_by_id" in extras
+                else None,
+                objectMarking=extras["object_marking_ids"]
+                if "object_marking_ids" in extras
+                else None,
+                objectLabel=extras["object_label_ids"]
+                if "object_label_ids" in extras
+                else [],
+                externalReferences=extras["external_references_ids"]
+                if "external_references_ids" in extras
+                else [],
+                revoked=stix_object["revoked"] if "revoked" in stix_object else None,
+                confidence=stix_object["confidence"]
+                if "confidence" in stix_object
+                else None,
+                lang=stix_object["lang"] if "lang" in stix_object else None,
+                created=stix_object["created"] if "created" in stix_object else None,
+                modified=stix_object["modified"] if "modified" in stix_object else None,
+                name=stix_object["name"],
+                description=self.opencti.stix2.convert_markdown(
+                    stix_object["description"]
+                )
+                if "description" in stix_object
+                else "",
+                aliases=self.opencti.stix2.pick_aliases(stix_object),
+                malware_types=stix_object["malware_types"]
+                if "malware_types" in stix_object
+                else None,
+                is_family=stix_object["is_family"]
+                if "is_family" in stix_object
+                else False,
+                first_seen=stix_object["first_seen"]
+                if "first_seen" in stix_object
+                else None,
+                last_seen=stix_object["last_seen"]
+                if "last_seen" in stix_object
+                else None,
+                architecture_execution_envs=stix_object["architecture_execution_envs"]
+                if "architecture_execution_envs" in stix_object
+                else None,
+                implementation_languages=stix_object["implementation_languages"]
+                if "implementation_languages" in stix_object
+                else None,
+                capabilities=stix_object["capabilities"]
+                if "capabilities" in stix_object
+                else None,
+                killChainPhases=extras["kill_chain_phases_ids"]
+                if "kill_chain_phases_ids" in extras
+                else None,
+                update=update,
             )
         else:
-            self.opencti.log("error", "Missing parameters: id or entity")
+            self.opencti.log(
+                "error", "[opencti_attack_pattern] Missing parameters: stixObject"
+            )
