@@ -274,6 +274,7 @@ class StixCoreRelationship:
     """
 
     def list(self, **kwargs):
+        element_id = kwargs.get("elementId", None)
         from_id = kwargs.get("fromId", None)
         from_types = kwargs.get("fromTypes", None)
         to_id = kwargs.get("toId", None)
@@ -284,14 +285,15 @@ class StixCoreRelationship:
         stop_time_start = kwargs.get("stopTimeStart", None)
         stop_time_stop = kwargs.get("stopTimeStop", None)
         filters = kwargs.get("filters", [])
-        first = kwargs.get("first", 500)
+        first = kwargs.get("first", 100)
         after = kwargs.get("after", None)
         order_by = kwargs.get("orderBy", None)
         order_mode = kwargs.get("orderMode", None)
+        custom_attributes = kwargs.get("customAttributes", None)
         get_all = kwargs.get("getAll", False)
         with_pagination = kwargs.get("withPagination", False)
         if get_all:
-            first = 500
+            first = 100
 
         self.opencti.log(
             "info",
@@ -305,12 +307,12 @@ class StixCoreRelationship:
         )
         query = (
             """
-                query StixCoreRelationships($fromId: String, $fromTypes: [String], $toId: String, $toTypes: [String], $relationship_type: String, $startTimeStart: DateTime, $startTimeStop: DateTime, $stopTimeStart: DateTime, $stopTimeStop: DateTime, $filters: [StixCoreRelationshipsFiltering], $first: Int, $after: ID, $orderBy: StixCoreRelationshipsOrdering, $orderMode: OrderingMode) {
-                    stixCoreRelationships(fromId: $fromId, fromTypes: $fromTypes, toId: $toId, toTypes: $toTypes, relationship_type: $relationship_type, startTimeStart: $startTimeStart, startTimeStop: $startTimeStop, stopTimeStart: $stopTimeStart, stopTimeStop: $stopTimeStop, filters: $filters, first: $first, after: $after, orderBy: $orderBy, orderMode: $orderMode) {
+                query StixCoreRelationships($elementId: String, $fromId: String, $fromTypes: [String], $toId: String, $toTypes: [String], $relationship_type: String, $startTimeStart: DateTime, $startTimeStop: DateTime, $stopTimeStart: DateTime, $stopTimeStop: DateTime, $filters: [StixCoreRelationshipsFiltering], $first: Int, $after: ID, $orderBy: StixCoreRelationshipsOrdering, $orderMode: OrderingMode) {
+                    stixCoreRelationships(elementId: $elementId, fromId: $fromId, fromTypes: $fromTypes, toId: $toId, toTypes: $toTypes, relationship_type: $relationship_type, startTimeStart: $startTimeStart, startTimeStop: $startTimeStop, stopTimeStart: $stopTimeStart, stopTimeStop: $stopTimeStop, filters: $filters, first: $first, after: $after, orderBy: $orderBy, orderMode: $orderMode) {
                         edges {
                             node {
                                 """
-            + self.properties
+            + (custom_attributes if custom_attributes is not None else self.properties)
             + """
                         }
                     }
@@ -328,6 +330,7 @@ class StixCoreRelationship:
         result = self.opencti.query(
             query,
             {
+                "elementId": element_id,
                 "fromId": from_id,
                 "fromTypes": from_types,
                 "toId": to_id,
@@ -344,14 +347,50 @@ class StixCoreRelationship:
                 "orderMode": order_mode,
             },
         )
-        return self.opencti.process_multiple(
-            result["data"]["stixCoreRelationships"], with_pagination
-        )
+        if get_all:
+            final_data = []
+            data = self.opencti.process_multiple(
+                result["data"]["stixCoreRelationships"]
+            )
+            final_data = final_data + data
+            while result["data"]["stixCoreRelationships"]["pageInfo"]["hasNextPage"]:
+                after = result["data"]["stixCoreRelationships"]["pageInfo"]["endCursor"]
+                self.opencti.log("info", "Listing StixCoreRelationships after " + after)
+                result = self.opencti.query(
+                    query,
+                    {
+                        "elementId": element_id,
+                        "fromId": from_id,
+                        "fromTypes": from_types,
+                        "toId": to_id,
+                        "toTypes": to_types,
+                        "relationship_type": relationship_type,
+                        "startTimeStart": start_time_start,
+                        "startTimeStop": start_time_stop,
+                        "stopTimeStart": stop_time_start,
+                        "stopTimeStop": stop_time_stop,
+                        "filters": filters,
+                        "first": first,
+                        "after": after,
+                        "orderBy": order_by,
+                        "orderMode": order_mode,
+                    },
+                )
+                data = self.opencti.process_multiple(
+                    result["data"]["stixCoreRelationships"]
+                )
+                final_data = final_data + data
+            return final_data
+        else:
+            return self.opencti.process_multiple(
+                result["data"]["stixCoreRelationships"], with_pagination
+            )
 
     """
         Read a stix_core_relationship object
 
         :param id: the id of the stix_core_relationship
+        :param elementId: the id of the entity of the relation
         :param fromId: the id of the source entity of the relation
         :param toId: the id of the target entity of the relation
         :param relationship_type: the relation type
@@ -364,6 +403,7 @@ class StixCoreRelationship:
 
     def read(self, **kwargs):
         id = kwargs.get("id", None)
+        element_id = kwargs.get("elementId", None)
         from_id = kwargs.get("fromId", None)
         to_id = kwargs.get("toId", None)
         relationship_type = kwargs.get("relationship_type", None)
@@ -395,6 +435,7 @@ class StixCoreRelationship:
             )
         elif from_id is not None and to_id is not None:
             result = self.list(
+                elementId=element_id,
                 fromId=from_id,
                 toId=to_id,
                 relationship_type=relationship_type,
@@ -584,7 +625,7 @@ class StixCoreRelationship:
                     "error", "Cannot add Marking-Definition, entity not found"
                 )
                 return False
-            if marking_definition_id in stix_core_relationship["markingDefinitionsIds"]:
+            if marking_definition_id in stix_core_relationship["objectMarkingIds"]:
                 return True
             else:
                 self.opencti.log(
@@ -1020,10 +1061,19 @@ class StixCoreRelationship:
                 stix_relation["relationship_type"] = "part-of"
             elif stix_relation["relationship_type"] == "localization":
                 stix_relation["relationship_type"] = "located-at"
-
+            source_ref = (
+                stix_relation["x_opencti_source_ref"]
+                if "x_opencti_source_ref" in stix_relation
+                else stix_relation["source_ref"]
+            )
+            target_ref = (
+                stix_relation["x_opencti_target_ref"]
+                if "x_opencti_target_ref" in stix_relation
+                else stix_relation["target_ref"]
+            )
             return self.create(
-                fromId=stix_relation["source_ref"],
-                toId=stix_relation["target_ref"],
+                fromId=source_ref,
+                toId=target_ref,
                 stix_id=stix_relation["id"],
                 relationship_type=stix_relation["relationship_type"],
                 description=self.opencti.stix2.convert_markdown(
