@@ -393,7 +393,7 @@ class StixDomainObject:
         types = kwargs.get("types", None)
         filters = kwargs.get("filters", None)
         search = kwargs.get("search", None)
-        first = kwargs.get("first", 500)
+        first = kwargs.get("first", 100)
         after = kwargs.get("after", None)
         order_by = kwargs.get("orderBy", None)
         order_mode = kwargs.get("orderMode", None)
@@ -401,7 +401,7 @@ class StixDomainObject:
         get_all = kwargs.get("getAll", False)
         with_pagination = kwargs.get("withPagination", False)
         if get_all:
-            first = 500
+            first = 100
 
         self.opencti.log(
             "info",
@@ -839,7 +839,7 @@ class StixDomainObject:
                     "error", "Cannot add Marking-Definition, entity not found"
                 )
                 return False
-            if marking_definition_id in stix_domain_object["markingDefinitionsIds"]:
+            if marking_definition_id in stix_domain_object["objectMarkingIds"]:
                 return True
             else:
                 self.opencti.log(
