@@ -125,14 +125,14 @@ class Tool:
     def list(self, **kwargs):
         filters = kwargs.get("filters", None)
         search = kwargs.get("search", None)
-        first = kwargs.get("first", 500)
+        first = kwargs.get("first", 100)
         after = kwargs.get("after", None)
         order_by = kwargs.get("orderBy", None)
         order_mode = kwargs.get("orderMode", None)
         get_all = kwargs.get("getAll", False)
         with_pagination = kwargs.get("withPagination", False)
         if get_all:
-            first = 500
+            first = 100
 
         self.opencti.log(
             "info", "Listing Tools with filters " + json.dumps(filters) + "."
@@ -170,7 +170,31 @@ class Tool:
                 "orderMode": order_mode,
             },
         )
-        return self.opencti.process_multiple(result["data"]["tools"], with_pagination)
+        if get_all:
+            final_data = []
+            data = self.opencti.process_multiple(result["data"]["tools"])
+            final_data = final_data + data
+            while result["data"]["tools"]["pageInfo"]["hasNextPage"]:
+                after = result["data"]["tools"]["pageInfo"]["endCursor"]
+                self.opencti.log("info", "Listing Tools after " + after)
+                result = self.opencti.query(
+                    query,
+                    {
+                        "filters": filters,
+                        "search": search,
+                        "first": first,
+                        "after": after,
+                        "orderBy": order_by,
+                        "orderMode": order_mode,
+                    },
+                )
+                data = self.opencti.process_multiple(result["data"]["tools"])
+                final_data = final_data + data
+            return final_data
+        else:
+            return self.opencti.process_multiple(
+                result["data"]["tools"], with_pagination
+            )
 
     """
         Read a Tool object
