@@ -912,8 +912,21 @@ class OpenCTIStix2:
 
         # Locations
         if LocationTypes.has_value(entity["entity_type"]):
+            entity["x_opencti_location_type"] = entity["entity_type"]
+            if entity["entity_type"] == "City":
+                entity["city"] = entity["name"]
+            elif entity["entity_type"] == "Country":
+                entity["country"] = entity["name"]
+            elif entity["entity_type"] == "Region":
+                entity["region"] = entity["name"]
             entity["entity_type"] = "Location"
 
+        # Indicators
+        if "pattern" in entity and "x-opencti-hostname" in entity["pattern"]:
+            entity["pattern"] = entity["pattern"].replace(
+                "x-opencti-hostname", "domain-name"
+            )
+
         # Flatten
         if "objectLabel" in entity and len(entity["objectLabel"]) > 0:
             entity["labels"] = []
@@ -958,6 +971,11 @@ class OpenCTIStix2:
         if "externalReferences" in entity:
             del entity["externalReferences"]
             del entity["externalReferencesIds"]
+        if "hashes" in entity:
+            hashes = entity["hashes"]
+            entity["hashes"] = {}
+            for hash in hashes:
+                entity["hashes"][hash["algorithm"]] = hash["hash"]
 
         # Final
         entity["x_opencti_id"] = entity["id"]
@@ -979,7 +997,6 @@ class OpenCTIStix2:
         mode="simple",
         max_marking_definition_entity=None,
         no_custom_attributes=False,
-        description_as_id=False,
     ):
         if (
             self.check_max_marking_definition(
@@ -1010,17 +1027,10 @@ class OpenCTIStix2:
         if "createdBy" in entity:
             del entity["createdBy"]
             del entity["createdById"]
-
-        if description_as_id:
-            if "description" in entity:
-                entity["description"] = entity["id"]
-            elif "x_opencti_description" in entity:
-                if no_custom_attributes:
-                    entity["description"] = entity["id"]
-                else:
-                    entity["x_opencti_description"] = entity["id"]
-            else:
-                entity["description"] = entity["id"]
+        if "observables" in entity:
+            del entity["observables"]
+        if "observablesIds" in entity:
+            del entity["observablesIds"]
 
         entity_copy = entity.copy()
         if no_custom_attributes:
@@ -1114,9 +1124,19 @@ class OpenCTIStix2:
             objects_to_get.append(entity["to"]["standard_id"])
         if "to" in entity:
             del entity["to"]
+        # Stix Domain Object
+        if "attribute_abstract" in entity:
+            entity["abstract"] = entity["attribute_abstract"]
+            del entity["attribute_abstract"]
         # Stix Cyber Observable
         if "observable_value" in entity:
             del entity["observable_value"]
+        if "attribute_key" in entity:
+            entity["key"] = entity["attribute_key"]
+            del entity["attribute_key"]
+        if "attribute_date" in entity:
+            entity["date"] = entity["attribute_date"]
+            del entity["attribute_date"]
 
         result.append(entity)
 
@@ -1128,7 +1148,7 @@ class OpenCTIStix2:
                 uuids.append(x["id"])
             # Get extra relations (from)
             stix_core_relationships = self.opencti.stix_core_relationship.list(
-                fromId=entity["x_opencti_id"]
+                elementId=entity["x_opencti_id"]
             )
             for stix_core_relationship in stix_core_relationships:
                 if self.check_max_marking_definition(
@@ -1163,7 +1183,7 @@ class OpenCTIStix2:
                     )
             # Get sighting
             stix_sighting_relationships = self.opencti.stix_sighting_relationship.list(
-                fromId=entity["x_opencti_id"]
+                elementId=entity["x_opencti_id"]
             )
             for stix_sighting_relationship in stix_sighting_relationships:
                 if self.check_max_marking_definition(
@@ -1316,7 +1336,6 @@ class OpenCTIStix2:
         mode="simple",
         max_marking_definition=None,
         no_custom_attributes=False,
-        description_as_id=False,
     ):
         max_marking_definition_entity = (
             self.opencti.marking_definition.read(id=max_marking_definition)
@@ -1366,7 +1385,6 @@ class OpenCTIStix2:
             mode,
             max_marking_definition_entity,
             no_custom_attributes,
-            description_as_id,
         )
         if stix_objects is not None:
             bundle["objects"].extend(stix_objects)
@@ -1418,6 +1436,7 @@ class OpenCTIStix2:
 
         # List
         lister = {
+            "Stix-Domain-Object": self.opencti.stix_domain_object.list,
             "Attack-Pattern": self.opencti.attack_pattern.list,
             "Campaign": self.opencti.campaign.list,
             "Note": self.opencti.note.list,
@@ -1490,13 +1509,15 @@ class OpenCTIStix2:
                     if "where_sighted_refs" in item:
                         for where_sighted_ref in item["where_sighted_refs"]:
                             to_ids.append(where_sighted_ref)
-
                     # Import sighting_of_ref
-                    from_id = item["sighting_of_ref"]
+                    from_id = (
+                        item["x_opencti_sighting_of_ref"]
+                        if "x_opencti_sighting_of_ref" in item
+                        else item["sighting_of_ref"]
+                    )
                     if len(to_ids) > 0:
                         for to_id in to_ids:
                             self.import_sighting(item, from_id, to_id, update)
-
                     # Import observed_data_refs
                     if "observed_data_refs" in item:
                         for observed_data_ref in item["observed_data_refs"]:
